@@ -1,7 +1,7 @@
 package Org::To::Pod;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -30,7 +30,7 @@ Org::To::Pod - Export Org document to Pod
 
 =head1 VERSION
 
-This document describes version 0.02 of Org::To::Pod (from Perl distribution Org-To-Pod), released on 2015-08-18.
+This document describes version 0.03 of Org::To::Pod (from Perl distribution Org-To-Pod), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ NOT YET IMPLEMENTED.
 
 =head2 org_to_pod() -> [status, msg, result, meta]
 
-{en_US Export Org document to Pod}.
+Export Org document to Pod.
 
 No arguments.
 
